@@ -95,7 +95,7 @@ oh.call <- function(xpath, serverurl=getOption("SERVERURL"), token=getOption("TO
 	if(xhr$result == "success"){
 		return(xhr)
 	} else {
-		if(xhr$errors[[1]]$text == "The token is unknown."){
+		if(!is.null(xhr$errors[[1]]$text) && xhr$errors[[1]]$text == "The token is unknown."){
 			oh.logout();
 			stop("The token is unknown. Your session might have timed out. Please re-login.")
 		}
